@@ -13,11 +13,11 @@ use lib "$FindBin::Bin/../lib";
 
 use Protocol::DBus::Client;
 
-my $dbus = Protocol::DBus::Client::system();
+my $dbus = $> ? Protocol::DBus::Client::login_session() : Protocol::DBus::Client::system();
 
 $dbus->preserve_variant_signatures(1);
 
-$dbus->do_authn();
+$dbus->initialize();
 
 my $got_response;
 
