@@ -10,10 +10,7 @@ use Protocol::DBus::Path;
 
 use Data::Dumper;
 
-my @addrs = Protocol::DBus::Path::login_session_message_bus();
-
-my ($path) = map { $_->attribute('path') }  grep { $_->transport() eq 'unix' } @addrs;
-die 'No login session message bus!' if !$path;
+my $path = Protocol::DBus::Path::login_session_message_bus();
 
 my $addr = Socket::pack_sockaddr_un($path);
 
@@ -36,10 +33,11 @@ $dbus->send_call(
     signature => 's',
     member => 'GetAll',
     body => ['org.freedesktop.DBus'],
-)->then( sub {
-    $got_response = 1;
-    print "got getall response\n";
-    print Dumper shift;
-} );
+    on_return => sub {
+        $got_response = 1;
+        print "got getall response\n";
+        print Dumper shift;
+    },
+);
 
 $dbus->get_message() while !$got_response;
