@@ -3,10 +3,11 @@ package Protocol::DBus::WriteMsg;
 use strict;
 use warnings;
 
-use parent qw( IO::Framed::Write );
+use Socket ();
 
-use Socket;
-use Socket::MsgHdr;
+use Protocol::DBus::Socket ();
+
+use parent qw( IO::Framed::Write );
 
 my %fh_fds;
 
@@ -15,6 +16,8 @@ sub DESTROY {
 
     my $fh = delete $fh_fds{ $self->get_write_fh() };
 
+    $self->SUPER::DESTROY() if IO::Framed::Write->can('DESTROY');
+
     return;
 }
 
@@ -41,6 +44,8 @@ sub WRITE {
 
     # Only use sendmsg if we actually need to.
     if (my $fds_ar = $fh_fds{ $_[0] }[0]) {
+        die 'Socket::MsgHdr is not loaded!' if !Socket::MsgHdr->can('new');
+
         my $msg = Socket::MsgHdr->new( buf => $_[1] );
 
         $msg->cmsghdr(
@@ -48,7 +53,7 @@ sub WRITE {
             pack( 'I!*', @$fds_ar ),
         );
 
-        my $bytes = Socket::MsgHdr::sendmsg( $_[0], $msg );
+        my $bytes = Protocol::DBus::Socket::sendmsg_nosignal( $_[0], $msg, 0 );
 
         # NOTE: This assumes that, on an incomplete write, the ancillary
         # data (i.e., the FDs) will have been sent, and there is no need
@@ -61,7 +66,7 @@ sub WRITE {
         return $bytes;
     }
 
-    goto &IO::Framed::Write::WRITE;
+    return Protocol::DBus::Socket::send_nosignal( $_[0], $_[1], 0 );
 }
 
 1;
